@@ -50,6 +50,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk
@@ -117,6 +119,10 @@ class ServerlessClusterFromSnapshot(
 
         :stability: deprecated
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ServerlessClusterFromSnapshot.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ServerlessClusterFromSnapshotProps(
             engine=engine,
             snapshot_identifier=snapshot_identifier,
@@ -160,6 +166,9 @@ class ServerlessClusterFromSnapshot(
 
         :stability: deprecated
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ServerlessClusterFromSnapshot.add_rotation_multi_user)
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         options = aws_cdk.aws_rds.RotationMultiUserOptions(
             secret=secret,
             automatically_after=automatically_after,
@@ -218,6 +227,9 @@ class ServerlessClusterFromSnapshot(
 
         :stability: deprecated
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ServerlessClusterFromSnapshot.grant_data_api_access)
+            check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
         return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantDataApiAccess", [grantee]))
 
     @builtins.property # type: ignore[misc]
@@ -284,6 +296,9 @@ class ServerlessClusterFromSnapshot(
 
     @_enable_data_api.setter
     def _enable_data_api(self, value: typing.Optional[builtins.bool]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(ServerlessClusterFromSnapshot, "_enable_data_api").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableDataApi", value)
 
 
@@ -355,6 +370,24 @@ class ServerlessClusterFromSnapshotProps:
             scaling = aws_cdk.aws_rds.ServerlessScalingOptions(**scaling)
         if isinstance(vpc_subnets, dict):
             vpc_subnets = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnets)
+        if __debug__:
+            type_hints = typing.get_type_hints(ServerlessClusterFromSnapshotProps.__init__)
+            check_type(argname="argument engine", value=engine, expected_type=type_hints["engine"])
+            check_type(argname="argument snapshot_identifier", value=snapshot_identifier, expected_type=type_hints["snapshot_identifier"])
+            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
+            check_type(argname="argument backup_retention", value=backup_retention, expected_type=type_hints["backup_retention"])
+            check_type(argname="argument cluster_identifier", value=cluster_identifier, expected_type=type_hints["cluster_identifier"])
+            check_type(argname="argument credentials", value=credentials, expected_type=type_hints["credentials"])
+            check_type(argname="argument default_database_name", value=default_database_name, expected_type=type_hints["default_database_name"])
+            check_type(argname="argument deletion_protection", value=deletion_protection, expected_type=type_hints["deletion_protection"])
+            check_type(argname="argument enable_data_api", value=enable_data_api, expected_type=type_hints["enable_data_api"])
+            check_type(argname="argument parameter_group", value=parameter_group, expected_type=type_hints["parameter_group"])
+            check_type(argname="argument removal_policy", value=removal_policy, expected_type=type_hints["removal_policy"])
+            check_type(argname="argument scaling", value=scaling, expected_type=type_hints["scaling"])
+            check_type(argname="argument security_groups", value=security_groups, expected_type=type_hints["security_groups"])
+            check_type(argname="argument storage_encryption_key", value=storage_encryption_key, expected_type=type_hints["storage_encryption_key"])
+            check_type(argname="argument subnet_group", value=subnet_group, expected_type=type_hints["subnet_group"])
+            check_type(argname="argument vpc_subnets", value=vpc_subnets, expected_type=type_hints["vpc_subnets"])
         self._values: typing.Dict[str, typing.Any] = {
             "engine": engine,
             "snapshot_identifier": snapshot_identifier,
